@@ -681,29 +681,17 @@ the result.
          of the remaining cell. In worst case this is O(n^2), where n is number 
          of cells. 
 
-         But in real:
-         *(currently) maximum count of cell is 7*14 in hard
-         *check is called after first pair is taken
-         *n=7*14-2=96
-         *first cell is checked against 95 cells
-         *second cell is checked against 94 cells
-         *...
-         *95th cell is checked agaist 1 cell
-         *96th cell is checked agaist 0 cells
- 
-         *for i in range(95): s = s + i
-           ->4465 which is not problem at all
-
+         But game has so few cell: 14*7=98, it is fast enough.
         '''
         for y1 in range(self.model.height):      # height
             for x1 in range(self.model.width):    # width
                 if self.model.cell_at(x1,y1)!=None: 
-                    for y2 in range(y1,self.model.height):
-                        for x2 in range(x1,self.model.width):
+                    for y2 in range(y1,self.model.height):  #little optimized: do not check against rows that are already handled
+                        for x2 in range(self.model.width):
                             if self.model.can_move(x1,y1,x2,y2): #if returns anything but False
                                 #print "hint: ",x1,y1,x2,y2
                                 return True
-        
+
         #no valid pairs found
         return False
 
